==> xcoral_3.40.orig.tar.gz: xcoral-3.40/file_dict.c <==
/* ########################################################################

			      file_dict.c

   File: file_dict.c
   Path: /home/fournigault/c/X11/xcoral-2.31/file_dict.c
   Description: 
   Created: Fri Jan 27 11:01:24 MET 1995
   Author: Dominique Leveque
   Modified: Fri Jan 27 11:01:25 MET 1995
   Last maintained by: Dominique Leveque

   RCS $Revision$ $State$
   

   ########################################################################

   Note: 

   ########################################################################

   Copyright (c) : Dominique Leveque

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   ######################################################################## */


#if HAVE_STRING_H
#include <string.h>
#else
#include <strings.h>
#endif
#include <stdio.h>

#include "result_types.h"
#include "file_dict.h"
#include "browser_util.h"

/*------------------------------------------------------------------------------
//                         Le dictionnaire des fichiers
//------------------------------------------------------------------------------
*/

FileRec* file_dict[FILE_DICT_SIZE];

int      file_count = 0;


/*------------------------------------------------------------------------------
*/
FileRec* create_file (file_name)
  char* file_name;
{
	FileRec**  head;
  FileRec*   current_file;
	int        x_size;

	get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
  search_Rec(file_name, FileRec, head, current_file);
  if (current_file == Null) {
    x_size = sizeof(FileRec) + FILE_PLENGTH + strlen(file_name)  + 1;
    current_file = (FileRec*) xmalloc(x_size);
    if (current_file != Null) {
      create_Rec(file_name, FileRec, head, current_file, FILE_PREFIX, FILE_PLENGTH);
			file_count++;
		}
	}
  return(current_file);
}


/*------------------------------------------------------------------------------
*/
FileRec* find_file(file_name)
  char* file_name;
{
	FileRec**  head;
  FileRec*   current_file;

	get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
  search_Rec(file_name, FileRec, head, current_file);
  return(current_file);
}


/*------------------------------------------------------------------------------
*/
void remove_file(file_name)
  char* file_name;
{
  FileRec**  head;
  FileRec*   current_file;

	get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
  extract_Rec(file_name, FileRec, head, current_file);
	if (current_file != Null) {
	  free(current_file);
		--file_count;
	}
}


/*------------------------------------------------------------------------------
*/
void init_file() {
  int index;

  for (index = 0; index < FILE_DICT_SIZE; index++)
    file_dict[index] = Null;
}

==> xcoral-3.47.tar.gz: xcoral-3.47/file_dict.c <==
/* ########################################################################

			      file_dict.c

   File: file_dict.c
   Path: /home/fournigault/c/X11/xcoral-2.31/file_dict.c
   Description: 
   Created: Fri Jan 27 11:01:24 MET 1995
   Author: Dominique Leveque
   Modified: Fri Jan 27 11:01:25 MET 1995
   Last maintained by: Dominique Leveque

   RCS $Revision$ $State$
   

   ########################################################################

   Note: 

   ########################################################################

   Copyright (c) : Dominique Leveque

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   ######################################################################## */


#if HAVE_STRING_H
#include <string.h>
#else
#include <strings.h>
#endif
#include <stdio.h>

#include "result_types.h"
#include "file_dict.h"
#include "browser_util.h"

/*------------------------------------------------------------------------------
//                         Le dictionnaire des fichiers
//------------------------------------------------------------------------------
*/

FileRec* file_dict[FILE_DICT_SIZE];

int      file_count = 0;

char 	 Mark = 0;


/*------------------------------------------------------------------------------
*/
FileRec* create_file (file_name)
    char* file_name;
{
  FileRec**  head;
  FileRec*   current_file;
  int        x_size;
  
  get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
  search_Rec(file_name, FileRec, head, current_file);
  if (current_file == Null) {
    x_size = FILE_NAME_OFFSET + strlen(file_name)  + 1;
    current_file = (FileRec*) xmalloc(x_size);
    if (current_file != Null) {
      create_Rec(file_name, FileRec, head, current_file, FILE_PREFIX, FILE_PLENGTH);
      file_count++;
    }
  }
  return(current_file);
}


/*------------------------------------------------------------------------------
*/
FileRec* find_file(file_name)
    char* file_name;
{
  FileRec**  head;
  FileRec*   current_file;
  
  get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
  search_Rec(file_name, FileRec, head, current_file);
  return(current_file);
}


/*------------------------------------------------------------------------------
*/
void remove_file(file_name)
    char* file_name;
{
  FileRec **  head;
  FileRec*   current_file;
  
  if (file_name != 0) {
    get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
    extract_Rec(file_name, FileRec, head, current_file);
    if (current_file != Null) {
      free(current_file);	/* _name part of current_file */
      --file_count;
    }
  }
  else {
    FileRec ** pdict;
    int n;
    
    remove_Rec(file_dict, pdict, 1, FILE_DICT_SIZE, head, current_file, n, file_count, free);
  }
}

/*------------------------------------------------------------------------------
   mark the file which will be removed
*/
void mark_remove_file(file_name)
    char* file_name;
{
  FileRec**  head;
  FileRec*   current;
  
  get_head_Rec(file_name, file_dict, FILE_DICT_SIZE, head);
  current = *head;
  
  while (current != Null) {
    if (strcmp(current->_name, file_name) == 0) {
      /* does not free _name which is part of current */
      current->_name = &Mark;
      return;
    }
    else
      current = current->_next;
  }
}


/*------------------------------------------------------------------------------
   removes marked files
*/
void remove_marked_files()
{
  FileRec ** pdict;
  FileRec ** head;
  FileRec * cell;
  int n;

  remove_Rec(file_dict, pdict, cell->_name == &Mark, 
	     FILE_DICT_SIZE, head, cell, n, file_count, free);
}
